==> tecfy_core_package-1.1.39.tar.gz: lib/models/home/dashboard_base.model.dart <==
part of tecfy_core_client_package;

class DashboardItemBase extends BaseModel {
  late String type;
  late int order;
  late String dbName;
  late String titleAr;
  late String titleEn;
  late String descriptionAr;
  late String descriptionEn;
  String get title => LocalConfigService.isArabic ? titleAr : titleEn;
  late int size;
  late int natchNumber;
  dynamic value;
  bool isFrequentlyUpdated = false;
  // String? onClick;
  String? onClickType;
  String? onClickEntity;
  List<EntityFilter>? onClickFilter;

  Color? color;
  IconData? icon;
  @override
  String get displayName => title;

  @override
  String get idValue => dbName;

  DashboardItemBase.fromMap(Map<String, dynamic>? map) {
    if (map == null) return;
    type = map['type'];
    order = map['order'] ?? 0;
    dbName = map['dbName'];
    isFrequentlyUpdated = map['isFrequentlyUpdated'] ?? false;
    titleAr = map['titleAr'] ?? map['titleEn'] ?? "";
    titleEn = map['titleEn'] ?? map['titleAr'] ?? "";
    descriptionAr = map['descriptionAr'] ?? map['descriptionEn'] ?? "";
    descriptionEn = map['descriptionEn'] ?? map['descriptionAr'] ?? "";
    if (map['color'] != null) {
      color = HexColor(map['color']);
    }
    if (map['icon'] != null) {
      icon = EntityService.getIconFromString(map['icon'], null);
    }
    String? onClick = map['onClick'];
    if (onClick != null && onClick.isNotEmpty) {
      var lst = onClick.split(':');
      if (lst.length > 0) onClickType = lst[0];
      if (lst.length > 1) onClickEntity = lst[1];
      if (lst.length > 2) {
        var filter = lst.skip(2).join(':');
        onClickFilter = jsonDecode(filter)
            .map<EntityFilter>((e) => EntityFilter.fromJson(e))
            .toList();
      }
    }
  }
}

==> tecfy_core_package-1.1.42.tar.gz: lib/models/home/dashboard_base.model.dart <==
part of tecfy_core_client_package;

class DashboardItemBase extends BaseModel {
  late String type;
  late int order;
  late String dbName;
  late String titleAr;
  late String titleEn;
  late String descriptionAr;
  late String descriptionEn;
  String get title => LocalConfigService.isArabic ? titleAr : titleEn;
  late int size;
  late int natchNumber;
  dynamic value;
  bool isFrequentlyUpdated = false;
  // String? onClick;
  String? onClickType;
  String? onClickEntity;
  List<EntityFilter>? onClickFilter;

  Color? color;
  IconData? icon;
  @override
  String get displayName => title;

  @override
  String get idValue => dbName;

  DashboardItemBase.fromMap(Map<String, dynamic>? map) {
    if (map == null) return;
    type = map['type'];
    order = map['order'] ?? 0;
    dbName = map['dbName'];
    isFrequentlyUpdated = map['isFrequentlyUpdated'] ?? false;
    titleAr = map['titleAr'] ?? map['titleEn'] ?? "";
    titleEn = map['titleEn'] ?? map['titleAr'] ?? "";
    descriptionAr = map['descriptionAr'] ?? map['descriptionEn'] ?? "";
    descriptionEn = map['descriptionEn'] ?? map['descriptionAr'] ?? "";
    if (map['color'] != null && map['color'].toString().isNotEmpty) {
      if (map['color'] == "primary") {
        color = ThemeService.mainTextColor;
      } else {
        color = HexColor(map['color']);
        print('--------------------$color      -----  ${map['color']}');
      }
    }
    if (map['icon'] != null) {
      icon = EntityService.getIconFromString(map['icon'], null);
    }
    String? onClick = map['onClick'];
    if (onClick != null && onClick.isNotEmpty) {
      var lst = onClick.split(':');
      if (lst.length > 0) onClickType = lst[0];
      if (lst.length > 1) onClickEntity = lst[1];
      if (lst.length > 2) {
        var filter = lst.skip(2).join(':');
        onClickFilter = jsonDecode(filter)
            .map<EntityFilter>((e) => EntityFilter.fromJson(e))
            .toList();
      }
    }
  }
}
